#
# ================================================================
#
# Table definition for mod_benchmark module:
#
# ================================================================

# ----------------------------------------------------------------
#
# t_benchmark_log: contains one row per HTTP request for which
#		   the module is activated
# ----------------------------------------------------------------
DROP TABLE IF EXISTS t_benchmark_log;
CREATE TABLE t_benchmark_log (
	log_date 	DATETIME NOT NULL DEFAULT "2002-01-01 00:00:00",
	url_value	VARCHAR(250),
	arg_value	VARCHAR(250),
	fil_value	VARCHAR(250),
	log_status	INT NOT NULL DEFAULT 0,
	ben_sec		INT NOT NULL DEFAULT 0,
	ben_usec	INT NOT NULL DEFAULT 0,
	ben_ready	INT NOT NULL DEFAULT 0,
	ben_busy	INT NOT NULL DEFAULT 0,
	ben_pzombie	INT NOT NULL DEFAULT 0,
	ben_prunning	INT NOT NULL DEFAULT 0,
	ben_pstopped	INT NOT NULL DEFAULT 0,
	ben_psleeping	INT NOT NULL DEFAULT 0,
	ben_avgload	INT NOT NULL DEFAULT 0,
	ben_memuse	INT NOT NULL DEFAULT 0,
	ben_swapuse	INT NOT NULL DEFAULT 0,
	ben_cliaddr	INT NOT NULL DEFAULT 0,
	ben_srvaddr	INT NOT NULL DEFAULT 0,
	ben_srvport	INT NOT NULL DEFAULT 0
	);

# Notes:
# =====
#	Request Stats:
#	-------------
#	log_status: HTTP request status
#	ben_sec: time for response (in seconds)
#	ben_usec: microseconds part
#
#	Apache Stats:
#	------------
#	ben_ready: count of ready process
#	ben_busy: count of busy process
#
#	Process stats:
#	-------------
#	ben_pzombie: count of zombie process (unuseful ?)
#	ben_prunning: count of running process
#	ben_pstopped: count of stopped process
#	ben_psleeping: coutn of sleepin process
#
# 	The following percentages are given on a 1000 basis:
#
#	ben_avgload: average CPU load
#	ben_memuse: percentage of memory used
#	ben_swapuse: percentage of swap used
#
#	Fields added from version 1.2:
#	-----------------------------
#	fil_value: filename after URI translation
#	ben_cliaddr: IP address of client
#	ben_srvaddr: IP address of server
#
#	Fields added from version 1.5:
#	-----------------------------
#	ben_srvport: local port (HTTP, HTTPS...)
#

# ----------------------------------------------------------------
#
# t_benchmark_alert: contains one row per generated alert
#
# ----------------------------------------------------------------
DROP TABLE IF EXISTS t_benchmark_alert;
CREATE TABLE t_benchmark_alert (
	log_date 	DATETIME NOT NULL DEFAULT "2002-01-01 00:00:00",
	url_value	VARCHAR(250),
	arg_value	VARCHAR(250),
	fil_value	VARCHAR(250),
	ben_sec		INT NOT NULL DEFAULT 0,
	ben_usec	INT NOT NULL DEFAULT 0,
	ben_cliaddr	INT NOT NULL DEFAULT 0,
	ben_srvaddr	INT NOT NULL DEFAULT 0
	);

# Notes:
# =====
#
#	Fields added from version 1.2:
#	-----------------------------
#	fil_value: filename after URI translation
#	ben_cliaddr: IP address of client
#	ben_srvaddr: IP address of server
#

# ----------------------------------------------------------------
#
# t_benchmark_graph: contains the saved Reports
#
# ----------------------------------------------------------------
DROP TABLE IF EXISTS t_benchmark_graph;
CREATE TABLE t_benchmark_graph (
	gra_id		INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	gra_name	VARCHAR(64) NOT NULL DEFAULT "",
	gra_date	DATETIME NOT NULL DEFAULT "2002-01-01 00:00:00",
	gra_note	TEXT NOT NULL DEFAULT "",
	gra_blob	TEXT NOT NULL DEFAULT "",
	gra_width	INT NOT NULL DEFAULT 0,
	gra_height	INT NOT NULL DEFAULT 0
);

# Notes:
# =====
#
#	gra_blob: Reports are limited to 64Kb
#

# EOF
