#
# ================================================================
#
# Table definition for mod_benchmark module:
#
# ================================================================

# ----------------------------------------------------------------
#
# t_benchmark_log: contains one row per HTTP request for which
#		   the module is activated
# ----------------------------------------------------------------
CREATE TABLE t_benchmark_log (
	log_date 	DATETIME,
	url_value	VARCHAR(250),
	arg_value	VARCHAR(250),
	fil_value	VARCHAR(250),
	log_status	INT,
	ben_sec		INT,
	ben_usec	INT,
	ben_ready	INT,
	ben_busy	INT,
	ben_pzombie	INT,
	ben_prunning	INT,
	ben_pstopped	INT,
	ben_psleeping	INT,
	ben_avgload	INT,
	ben_memuse	INT,
	ben_swapuse	INT,
	ben_cliaddr	INT,
	ben_srvaddr	INT,
	ben_srvport	INT
	);

# Notes:
# =====
#	Request Stats:
#	-------------
#	log_status: HTTP request status
#	ben_sec: time for response (in seconds)
#	ben_usec: microseconds part
#
#	Apache Stats:
#	------------
#	ben_ready: count of ready process
#	ben_busy: count of busy process
#
#	Process stats:
#	-------------
#	ben_pzombie: count of zombie process (unuseful ?)
#	ben_prunning: count of running process
#	ben_pstopped: count of stopped process
#	ben_psleeping: coutn of sleepin process
#
# 	The following percentages are given on a 1000 basis:
#
#	ben_avgload: average CPU load
#	ben_memuse: percentage of memory used
#	ben_swapuse: percentage of swap used
#
#	Fields added from version 1.2:
#	-----------------------------
#	fil_value: filename after URI translation
#	ben_cliaddr: IP address of client
#	ben_srvaddr: IP address of server
#
#	Fields added from version 1.5:
#	-----------------------------
#	ben_srvport: local port (HTTP, HTTPS...)
#

# ----------------------------------------------------------------
#
# t_benchmark_alert: contains one row per generated alert
#
# ----------------------------------------------------------------
CREATE TABLE t_benchmark_alert (
	log_date 	DATETIME,
	url_value	VARCHAR(250),
	arg_value	VARCHAR(250),
	fil_value	VARCHAR(250),
	ben_sec		INT,
	ben_usec	INT,
	ben_cliaddr	INT,
	ben_srvaddr	INT
	);

# Notes:
# =====
#
#	Fields added from version 1.2:
#	-----------------------------
#	fil_value: filename after URI translation
#	ben_cliaddr: IP address of client
#	ben_srvaddr: IP address of server
#

# ----------------------------------------------------------------
#
# t_benchmark_graph: contains the saved Reports
#
# ----------------------------------------------------------------
CREATE TABLE t_benchmark_graph (
	gra_id		INT,
	gra_name	VARCHAR(64),
	gra_date	DATETIME,
	gra_note	TEXT,
	gra_blob	TEXT,
	gra_width	INT,
	gra_height	INT
);

# Notes:
# =====
#
#	gra_blob: Reports are limited to 64Kb
#
# EOF
