<?php
#
# ====================================================================
#
# This is the main script that displays the statistics.
#
# Date: 27 July 2002
# Author: J.Delamarche
# Version: 1.0
#
# Input Parameters:
#	stat_apache, stat_cpu, stat_mem, stat_swap, stat_time, stat_alert
#	scale: hour | dayweek | week | daymonth | month | last30d
#	graphtype: bargraph | linepoints | areagraph | piegraph
#	sday,smonth,syear (from date)
#	eday,emonth,eyear (to day)
#	request: all | url...
#	threshold
#
# Output: 
#	creates the $imgname (if cache obsolete)
#	fill the $stat_output variable (if possible)
#	then output "comstat.htm" file
#
# --------------------------------------------------------------------
#
# TODO: yscale management for different info
# TODO: other stat integration (sort the URL by response time...)
#
# ====================================================================
#

# --------------------------------------------------
# Check that the code name is attached to the client:
# --------------------------------------------------
include_once "messages.inc.php";
include_once "dbbenchmark.inc.php";
include_once "globals.inc.php";

$db = new CDBBenchmark($dbtype,$dbname,$dbserver,$dbuser,$dbpwd);

# ----------------
# Global variables:
# ----------------
$graphwidth 	= 680;
$graphheight 	= 340;
$curdir		= dirname($HTTP_SERVER_VARS["SCRIPT_FILENAME"]);
$bgcolor	= "white";
$barspacing	= 8;

# ----------------------
# Compute the statistics:
# ----------------------
include "graph1.inc.php";
include "table.inc.php";

# create the table and add the styles:
$table = new make_table();
$table->set_value("align","center");
$table->set_value("width",$graphwidth);

# Set the filters:
$db->SetStartDate($syear."-".$smonth."-".$sday." 00:00:00");
$db->SetEndDate($eyear."-".$emonth."-".$eday." 23:59:59");
$db->SetThreshold($threshold);
$db->SetRequest($request);

# Build the list of required stats:
$statlist = Array();
if ($stat_apache) $statlist[] = "apache";
if ($stat_cpu)    $statlist[] = "cpu";
if ($stat_mem)    $statlist[] = "mem";
if ($stat_swap)   $statlist[] = "swap";
if ($stat_time)   $statlist[] = "time";
if ($stat_alert)  $statlist[] = "alert";

$yscale = 1;
$allres = Array();

if ($scale == "hour") {
	$xlabel = BenchGetText("GS_Hour");
	for ( $s = 0 ; $s < count($statlist) ; $s++ ) {
		$res = $db->StatPerHour($statlist[$s]);
		DisplayPerHourData($allres,$res,$statlist[$s]);
	}

	DisplayPerHourAllData($allres,"all");
}
else if ($scale == "dayweek") {
	$xlabel = BenchGetText("GS_DayWeek");
	for ( $s = 0 ; $s < count($statlist) ; $s++ ) {
		$res = $db->StatPerDayOfWeek($statlist[$s]);
		DisplayPerDayOfWeekData($allres,$res,$statlist[$s]);
	}

	DisplayPerDayOfWeekAllData($allres,"all");
}
else if ($scale == "week") {
	$xlabel = BenchGetText("GS_Week");
	for ( $s = 0 ; $s < count($statlist) ; $s++ ) {
		$res = $db->StatPerWeek($statlist[$s]);
		DisplayPerWeekData($allres,$res,$statlist[$s]);
	}

	DisplayPerWeekAllData($allres,"all");
}
else if ($scale == "daymonth") {
	$xlabel = BenchGetText("GS_DayMonth");
	for ( $s = 0 ; $s < count($statlist) ; $s++ ) {
		$res = $db->StatPerDayOfMonth($statlist[$s]);
		DisplayPerDayOfMonthData($allres,$res,$statlist[$s]);
	}

	DisplayPerDayOfMonthAllData($allres,"all");
}
else if ($scale == "last30d") {
	$xlabel = BenchGetText("GS_Last30d");

	$dateparts = getdate();
	$year2 = $dateparts["year"]; $month2 = $dateparts["mon"]; $day2 = $dateparts["mday"];
	$dateparts = getdate(time() - 29 * 24 * 60 * 60);
	$year1 = $dateparts["year"]; $month1 = $dateparts["mon"]; $day1 = $dateparts["mday"];
	#echo $year1."/".$month1."/".$day1." ".$year2."/".$month2."/".$day2."<br>";

	for ( $s = 0 ; $s < count($statlist) ; $s++ ) {
		$res = $db->StatPerLast30d($statlist[$s],$year1,$month1,$day1,$year2,$month2,$day2);
		DisplayPerLast30dData($allres,$res,$statlist[$s]);
	}

	DisplayPerLast30dAllData($allres,"all");
}
else if ($scale == "month") {
	$xlabel = BenchGetText("GS_Month");
	for ( $s = 0 ; $s < count($statlist) ; $s++ ) {
		$res = $db->StatPerMonth($statlist[$s]);
		DisplayPerMonthData($allres,$res,$statlist[$s]);
	}

	DisplayPerMonthAllData($allres,"all");
}
else die("Unknown scale ($scale)");

# -------------------------
# Result output:
# -------------------------
SendHTML("comstat.htm");
die;

# =========================================================================
# Internal Functions:
# =========================================================================

# -----------------
# Display Functions:
# -----------------
function DisplayPerHourData(&$allres,&$res,$stat)
{
	global $yscale,$stat_output,$graphwidth;

	GetLegend($stat,&$title,&$ylabel,&$legend);

	$table = new make_table();
	$table->set_value("align","center");
	$table->set_value("width",$graphwidth);

	// Display a graph from 0 to 23 hours:
	// X values:
	for ( $idx = 0 ; $idx < 24 ; $idx++ ) $data[0][$idx] = $idx;
	// Y values:
	$grnu = count($allres);
	for ( $idx = 0 ; $idx < 24 ; $idx++ ) {
		$data[1][$idx] = floor($res[$idx] / $yscale);
		$allres[$grnu][$idx] = $data[1][$idx];
	}

	// Create the table:
	$table->add_row();
	$table->add_cell($title,2);
	for ( $idx = 0 ; $idx < 24 ; $idx++ ) {
		$table->add_row();
		$table->add_cell($idx."-".($idx+1),0,"50%");
		$table->add_cell($data[1][$idx],0,"50%");
	}

	$xlabel = BenchGetText("GS_Hour");
	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);

	$stat_output .= "<p align=center>".$table->output_table()."</p>\n";
}

function DisplayPerHourAllData(&$allres,$stat)
{
	// Display a graph from 0 to 23 hours:
	// X values:
	for ( $idx = 0 ; $idx < 24 ; $idx++ ) $data[0][$idx] = $idx;
	// Y values:
	for ( $idx = 0 ; $idx < 24 ; $idx++ ) {
		for ( $c = 0 ; $c < count($allres) ; $c++ ) {
			$data[1+$c][$idx] = $allres[$c][$idx];
		}
	}

	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);
}

function DisplayPerDayOfWeekData(&$allres,&$res,$stat)
{
	global $yscale,$stat_output,$graphwidth;

	GetLegend($stat,&$title,&$ylabel,&$legend);

	$table = new make_table();
	$table->set_value("align","center");
	$table->set_value("width",$graphwidth);

	// Display a graph from 1 to 7 hours:
	// X values:
	for ( $idx = 0 ; $idx < 7 ; $idx++ ) $data[0][$idx] = GetDay($idx);

	// Y values:
	$grnu = count($allres);
	for ( $idx = 1 ; $idx <= 7 ; $idx++ ) {
		$data[1][$idx-1] = floor($res[$idx] / $yscale);
		$allres[$grnu][$idx-1] = $data[1][$idx-1];
	}

	// Create the table:
	$table->add_row();
	$table->add_cell($title,2);
	for ( $idx = 0 ; $idx < 7 ; $idx++ ) {
		$table->add_row();
		$table->add_cell($data[0][$idx],0,"50%");
		$table->add_cell($data[1][$idx],0,"50%");
	}

	$xlabel = BenchGetText("GS_DayWeek");
	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);

	$stat_output .= "<p align=center>".$table->output_table()."</p>\n";
}

function DisplayPerDayOfWeekAllData(&$allres,$stat)
{
	// X values:
	for ( $idx = 0 ; $idx < 7 ; $idx++ ) $data[0][$idx] = GetDay($idx);

	// Y values:
	for ( $idx = 0 ; $idx < 7 ; $idx++ ) {
		for ( $c = 0 ; $c < count($allres) ; $c++ ) {
			$data[1+$c][$idx] = $allres[$c][$idx];
		}
	}

	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);
}

function DisplayPerWeekData(&$allres,&$res,$stat)
{
	global $yscale,$stat_output,$graphwidth;

	GetLegend($stat,&$title,&$ylabel,&$legend);

	$table = new make_table();
	$table->set_value("align","center");
	$table->set_value("width",$graphwidth);

	// Display a graph from 1 to 52 weeks:
	// X values:
	for ( $idx = 1 ; $idx <= 52 ; $idx++ ) if ($idx % 2) $data[0][$idx-1] = $idx; else $data[0][$idx-1] = "";

	// Y values:
	$grnu = count($allres);
	for ( $idx = 1 ; $idx <= 52 ; $idx++ ) {
		$data[1][$idx-1] = floor($res[$idx] / $yscale);
		$allres[$grnu][$idx-1] = $data[1][$idx-1];
	}

	// Create the table:
	$table->add_row();
	$table->add_cell($title,2);
	for ( $idx = 0 ; $idx < 52 ; $idx++ ) {
		$table->add_row();
		$table->add_cell(BenchGetText("GS_Week")." ".($idx+1),0,"50%");
		$table->add_cell($data[1][$idx],0,"50%");
	}

	$xlabel = BenchGetText("GS_Week");
	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);

	$stat_output .= "<p align=center>".$table->output_table()."</p>\n";
}

function DisplayPerWeekAllData(&$allres,$stat)
{
	// X values:
	for ( $idx = 1 ; $idx <= 52 ; $idx++ ) if ($idx % 2) $data[0][$idx-1] = $idx; else $data[0][$idx-1] = "";

	// Y values:
	for ( $idx = 0 ; $idx < 52 ; $idx++ ) {
		for ( $c = 0 ; $c < count($allres) ; $c++ ) {
			$data[1+$c][$idx] = $allres[$c][$idx];
		}
	}

	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);
}

function DisplayPerDayOfMonthData(&$allres,&$res,$stat)
{
	global $yscale,$stat_output,$graphwidth;

	GetLegend($stat,&$title,&$ylabel,&$legend);

	$table = new make_table();
	$table->set_value("align","center");
	$table->set_value("width",$graphwidth);

	// Display a graph from 1 to lastday hours:
	// X values:
	for ( $idx = 1 ; $idx <= count($res) ; $idx++ ) $data[0][$idx-1] = $idx;
	// Y values:
	$grnu = count($allres);
	for ( $idx = 1 ; $idx <= count($res) ; $idx++ ) {
		$data[1][$idx-1] = floor($res[$idx] / $yscale);
		$allres[$grnu][$idx-1] = $data[1][$idx-1];
	}

	// Create the table:
	$table->add_row();
	$table->add_cell($title,2);
	for ( $idx = 0 ; $idx < count($res) ; $idx++ ) {
		$table->add_row();
		$table->add_cell(($idx+1),0,"50%");
		$table->add_cell($data[1][$idx],0,"50%");
	}

	$xlabel = BenchGetText("GS_DayMonth");
	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);

	$stat_output .= "<p align=center>".$table->output_table()."</p>\n";
}

function DisplayPerDayOfMonthAllData(&$allres,$stat)
{
	// X values:
	for ( $idx = 1 ; $idx <= count($allres[0]) ; $idx++ ) $data[0][$idx-1] = $idx;

	// Y values:
	for ( $idx = 1 ; $idx <= count($allres[0]) ; $idx++ ) {
		for ( $c = 0 ; $c < count($allres) ; $c++ ) {
			$data[1+$c][$idx] = $allres[$c][$idx];
		}
	}

	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);
}

function DisplayPerMonthData(&$allres,&$res,$stat)
{
	global $yscale,$stat_output,$graphwidth;

	GetLegend($stat,&$title,&$ylabel,&$legend);

	$table = new make_table();
	$table->set_value("align","center");
	$table->set_value("width",$graphwidth);

	// Display a graph from 1 to 12 months:
	// X values:
	for ( $idx = 1 ; $idx <= 12 ; $idx++ ) {
		if ($idx < 10) $data[0][$idx-1] = ShortMonth("0".$idx);
		else $data[0][$idx-1] = ShortMonth("$idx");
	}

	// Y values:
	$grnu = count($allres);
	for ( $idx = 1 ; $idx <= 12 ; $idx++ ) {
		$data[1][$idx-1] = floor($res[$idx] / $yscale);
		$allres[$grnu][$idx-1] = $data[1][$idx-1];
	}

	// Create the table:
	$table->add_row();
	$table->add_cell($title,2);
	for ( $idx = 0 ; $idx < 12 ; $idx++ ) {
		$table->add_row();
		$m = $idx+1; if ($m < 10) $m = "0".$m;
		$table->add_cell(FullMonth("$m"),0,"50%");
		$table->add_cell($data[1][$idx],0,"50%");
	}

	$xlabel = BenchGetText("GS_Month");
	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);

	$stat_output .= "<p align=center>".$table->output_table()."</p>\n";
}

function DisplayPerMonthAllData(&$allres,$stat)
{
	// Display a graph from 1 to 12 months:
	// X values:
	for ( $idx = 1 ; $idx <= 12 ; $idx++ ) {
		if ($idx < 10) $data[0][$idx-1] = ShortMonth("0".$idx);
		else $data[0][$idx-1] = ShortMonth("$idx");
	}

	// Y values:
	for ( $idx = 0 ; $idx < 12 ; $idx++ ) {
		for ( $c = 0 ; $c < count($allres) ; $c++ ) {
			$data[1+$c][$idx] = $allres[$c][$idx];
		}
	}

	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);
}

function DisplayPerLast30dData(&$allres,&$res,$stat)
{
	global $yscale,$stat_output,$graphwidth;

	GetLegend($stat,&$title,&$ylabel,&$legend);

	$table = new make_table();
	$table->set_value("align","center");
	$table->set_value("width",$graphwidth);

	// Display a graph from 1 to lastday hours:
	// X values:
	for ( $idx = 1 ; $idx <= count($res) ; $idx++ ) $data[0][$idx-1] = (31-$idx);
	// Y values:
	$grnu = count($allres);
	for ( $idx = 1 ; $idx <= count($res) ; $idx++ ) {
		$data[1][$idx-1] = floor($res[$idx] / $yscale);
		$allres[$grnu][$idx-1] = $data[1][$idx-1];
	}

	// Create the table:
	$table->add_row();
	$table->add_cell($title,2);
	for ( $idx = 0 ; $idx < count($res) ; $idx++ ) {
		$table->add_row();
		$dateparts = getdate(time() - (29-$idx) * 24 * 60 * 60);
		$table->add_cell($dateparts["mday"]."/".$dateparts["mon"]."/".$dateparts["year"],0,"50%");
		$table->add_cell($data[1][$idx],0,"50%");
	}

	$xlabel = BenchGetText("GS_Last30d");
	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);

	$stat_output .= "<p align=center>".$table->output_table()."</p>\n";
}

function DisplayPerLast30dAllData(&$allres,$stat)
{
	// Display a graph from 1 to 12 months:
	// X values:
	for ( $idx = 1 ; $idx <= count($allres[0]) ; $idx++ ) $data[0][$idx-1] = (31-$idx);

	// Y values:
	for ( $idx = 1 ; $idx <= count($allres[0]) ; $idx++ ) {
		for ( $c = 0 ; $c < count($allres) ; $c++ ) {
			$data[1+$c][$idx] = $allres[$c][$idx];
		}
	}

	CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat);
}

# --------------------------------
# Create a Graph with given values:
# --------------------------------
function CreateGraph($title,$xlabel,$ylabel,$legend,$bgcolor,$data,$stat)
{
	global $graphtype,$barspacing,$graphwidth,$graphheight,$stat_output;
	global $statlist;

	if (empty($graphtype)) 
		$graphtype = "bargraph";

	phpplot(array( 	"grid" 			=> true,
			"cubic"			=> true,
			"size"			=> array($graphwidth,$graphheight),
			"title_text"		=> $title,
			"yaxis_labeltext"	=> $ylabel,
			"xaxis_labeltext"	=> $xlabel,
			"background"		=> $bgcolor,
			//"legend_shift"		=> array(-430,250)
		));
	phpdata($data);

	// drawsets:
	for ( $d = 1 ; $d < count($data) ; $d++ ) $drawsets[] = $d;

	// legends:
	if ($stat == "all") {
		for ( $s = 0 ; $s < count($statlist) ; $s++ )
			$leg[] = BenchGetText("LE_".$statlist[$s]);
	}
	else {
		$leg = array($legend);
	}

	phpdraw($graphtype,
		array(	"drawsets"		=> $drawsets,
			"legend"		=> $leg,
			"barspacing"		=> $barspacing)
		);

	$extra = time();
	$imgname = GetImageName(false,$stat,$extra);
	phpshow("$imgname","jpeg");

	// Write the cached file:
	$imgname = GetImageName(true,$stat,$extra);

	$stat_output .= "<p align=center><img src=$imgname></p>\n";
}

function GetLegend($stat,&$title,&$ylabel,&$legend)
{
	# To add a statistics, just add three labels in "messages.inc.php":
	$title  = BenchGetText("TI_$stat");
	$ylabel = BenchGetText("YL_$stat");
	$legend = BenchGetText("LE_$stat");
}

#
# ----------------------------------
# Generate the unique image filename:
# ----------------------------------
#
# Files are removed by a batch when they are older that the max time.
#
function GetImageName($urlformat,$stat,$extra)
{
	global $curdir,$scale,$graphtype;

	if ($urlformat)
		return "stats/$stat"."-$scale"."-$graphtype"."-$extra.jpg";
	else
		return "$curdir/stats/$stat"."-$scale"."-$graphtype"."-$extra.jpg";
}

# --------------------------------------------
# Return the common HTML for all the statistic:
# --------------------------------------------
function SendHTML($filename)
{
	global $stat_output;

	include "$filename";
}
?>
